%GARCH versus ES simulated series
disp(' Exponential smoothing and GARCH differences in unconditional forecasting (simulated series) =============')
dim=300;                                                                    %Number of periods to be simulated
alpha=[0.75 0.2];                                                           %Sets parameters of the simulations: model 1 vs. model 2
beta=[0.2 0.75];
omega=[1 2] ;

u0=randn;
garch=NaN(dim,length(alpha)+length(omega));
uncond_var=omega(1)/(1-alpha(1)-beta(1));                                   %Initial value for the variance
epsilon0=u0*sqrt(uncond_var);
garch(1,1)=omega(1)+alpha(1)*(epsilon0^2)+beta(1)*uncond_var;               %Model 1: Low unconditional variance, low beta, high alpha
uncond_var=omega(1)/(1-alpha(2)-beta(2));                                   %Initial value for the variance
epsilon0=u0*sqrt(uncond_var);
garch(1,2)=omega(1)+alpha(2)*(epsilon0^2)+beta(2)*uncond_var;               %Model 2: Low unconditional variance, high beta, low alpha
uncond_var=omega(2)/(1-alpha(1)-beta(1));                                   %Initial value for the variancegarch(1,3)=omega(2)+alpha(1)*(epsilon0^2)+beta(1)*uncond_var;               %Model 3: High unconditional variance, low  beta, high alpha
epsilon0=u0*sqrt(uncond_var);
garch(1,3)=omega(2)+alpha(1)*(epsilon0^2)+beta(1)*uncond_var;               %Model 4: High unconditional variance, high beta, low alpha
uncond_var=omega(2)/(1-alpha(2)-beta(2));                                   %Initial value for the variancegarch(1,3)=omega(2)+alpha(1)*(epsilon0^2)+beta(1)*uncond_var;               %Model 3: High unconditional variance, low  beta, high alpha
epsilon0=u0*sqrt(uncond_var);
garch(1,4)=omega(2)+alpha(2)*(epsilon0^2)+beta(2)*uncond_var;               %Model 4: High unconditional variance, high beta, low alpha
ut=randn(dim,1);

for j=1:length(alpha)
    for i=2:dim
        epsilon=sqrt(garch(i-1,j))*ut(i);
        garch(i,j)=omega(1)+alpha(j)*epsilon^2+beta(j)*garch(i-1,j);
    end
end

for j=3:length(alpha)+length(omega)
    for i=2:dim
        epsilon=sqrt(garch(i-1,j))*ut(i);
        garch(i,j)=omega(2)+alpha(j-2)*epsilon^2+beta(j-2)*garch(i-1,j);
    end
end

figure
t=1:dim;
subplot(1,2,1)
plot(t',garch(:,1),'b',t',garch(:,2),'g','LineWidth',1.5);
xlim([t(1) t(end)])
ylim([1 500])
grid on
title('GARCH(1,1) with Different Coefficients + Low Uncond. Variance, omega=1')
legend('Model 1: a1=0.7 b1=0.2','Model 2: a1=0.2 b1=0.7',2)

subplot(1,2,2)
plot(t',garch(:,3),'b',t',garch(:,4),'g','LineWidth',1.5);
xlim([t(1) t(end)])
ylim([1 500])
grid on
title('GARCH(1,1) with Different Coefficients + High Uncond. Variance, omega=2')
legend('Model 3: a1=0.7 b1=0.2','Model 4: a1=0.2 b1=0.7')

horz=250;                                                                   %Computes standard deviation forecasts over 250 periods
A=NaN(horz,1);
garch_sigma_sq_t_plus_one_a=omega(1)+alpha(1)*epsilon^2+beta(1)*garch(end,1); %Initialize from last shock obtained in the simulations
garch_sigma_sq_t_plus_one_b=omega(1)+alpha(2)*epsilon^2+beta(2)*garch(end,2); 

%Derives forecasts under Model 1
A(1)=garch_sigma_sq_t_plus_one_a;
uncond_var=omega(1)/(1-alpha(1)-beta(1));                                   %Initial value for the variance
for i=2:horz
    A(i)=uncond_var+((alpha(1)+beta(1))^(i-1))*(garch_sigma_sq_t_plus_one_a-uncond_var);
end
garch_forecast_a=sqrt(A);
lambda_a=(garch_sigma_sq_t_plus_one_a-epsilon^2)/(garch(end,1)-epsilon^2);    %RiskMetrics lambda consistent with the variance forecast
es_forecast_a=lambda*garch_forecast_a(1)+(1-lambda)*epsilon^2;
es_forecast_a=sqrt(es_forecast_a).*ones(horz,1);

%Derives forecasts under Model 2
A(1)=garch_sigma_sq_t_plus_one_b;
uncond_var=omega(1)/(1-alpha(2)-beta(2));                                   %Initial value for the variance
for i=2:horz
    A(i)=uncond_var+((alpha(2)+beta(2))^(i-1))*(garch_sigma_sq_t_plus_one_b-uncond_var);
end
garch_forecast_b=sqrt(A);
lambda_b=(garch_sigma_sq_t_plus_one_b-epsilon^2)/(garch(end,2)-epsilon^2);    %RiskMetrics lambda consistent with the variance forecast
es_forecast_b=lambda*garch_forecast_b(1)+(1-lambda)*epsilon^2;
es_forecast_b=sqrt(es_forecast_b).*ones(horz,1);

figure(8)
t=1:horz;
subplot(2,1,1)
plot(t',garch_forecast_a,t',es_forecast_a,'LineWidth',2)
xlabel('Forecast Horizon (days)')
ylabel('% volatility (%)')
grid on
title('250 days volatility forecast')
legend(strcat('GARCH(1,1) forecast, a1=',num2str(alpha(1)),' b1=',num2str(beta(1))),strcat('ES forecast, lambda=',num2str(lambda_a)))

subplot(2,1,2)
plot(t',garch_forecast_b,t',es_forecast_b,'LineWidth',2)
xlabel('Forecast Horizon (days)')
ylabel('% volatility (%)')
grid on
title('250 days volatility forecast')
legend(strcat('GARCH(1,1) forecast, a1=',num2str(alpha(2)),' b1=',num2str(beta(2))),strcat('ES forecast, lambda=',num2str(lambda_b)))