
disp('================= Comparing GJR, NGARCH, and EGARCH variance estimates ==================')

% NGARCH(1,1) model estimated by MLE, using user-prodided log-likelihood
% function through 'ngarch'; this procedure uses Matlab unconstrained
% optimization fminsearch (please press F1 over 'fminsearch')
par_initial(1:4,1)=[0.00005;0.1;0.05;0.85];                                       
[param_ng,mle_ng]=fminsearch('ngarch',par_initial,optimset('Display','iter'),Port(ss:se,:));       
                                                                            %function [sumloglik,z,cond_var] = ngarch(par,y)
                                                                            %Compoutes NGARCH log-likelihood with zero conditional mean
                                                                            % Inputs:
                                                                            %   par: 4x1 vector of NGARCH parameters (omega;alpha;theta;beta)
                                                                            %   y:   vector of returns
                                                                            %
                                                                            % Outputs:
                                                                            %   sumloglik: (scalar) value of likelihood function (normal dist)
                                                                            %   z: vector of standardized returns
                                                                            %   cond_var: conditional VARIANCE 

                                                                            %fminsearch finds *MINIMUM* of unconstrained multivariable function using 
                                                                            %derivative-free method
                                                                            %Syntax: [x,fval] = fminsearch(fun,x0,options)
                                                                            %fminsearch finds the minimum of a scalar function of several variables, 
                                                                            %starting at an initial estimate. This is generally referred to as 
                                                                            %unconstrained nonlinear optimization.
                                                                            %fminsearch(fun,x0) starts at the point x0 and returns a value x that is a 
                                                                            %local minimizer of the function described in fun. x0 can be a scalar, vector, 
                                                                            %or matrix. fun is a function handle.
                                                                            %fminsearch(fun,x0,options) minimizes with the optimization parameters 
                                                                            %specified in the structure options. You can define these parameters using the 
                                                                            %optimset function. fminsearch uses these options structure fields:
                                                                            %   Display: 'off' displays no output; 'iter' displays output at each iteration;
                                                                            %       'final' displays just the final output; 'notify' (default) displays output 
                                                                            %       only if the function does not converge.
                                                                            %   FunValCheck: Check whether objective function values are valid, 'on'/'off'
                                                                            %   MaxFunEvals: Maximum number of function evaluations allowed
                                                                            %   MaxIter: Maximum number of iterations allowed
                                                                            %   PlotFcns: Plots various measures of progress while the algorithm executes, 
                                                                            %       select from predefined plots or write your own. Examples: @optimplotx 
                                                                            %       plots the current point; optimplotfval plots the function value; 
                                                                            %       @optimplotfunccount plots the function count.
                                                                            %   TolFun: Termination tolerance on the function value
                                                                            %   TolX: Termination tolerance on x
%Computes optimized log-lik function and conditional variances based on
%optimized parameter estimates
[mle,z_ng,cond_var_ng]=ngarch(param_ng,Port(ss:se,:));          %This corresponds to one additional, final call of the procedure 'ngarch'                
                                                                            %Notice that cond_var_ng is saved for later use
%Labels NGARCH(1,1) parameters                                                                                         
omega=param_ng(1,1);
alpha=param_ng(2,1);
theta=param_ng(3,1);
beta=param_ng(4,1);
ret=Port(ss:se,:);
%Builds in-sample variance estimates from the NGARCH(1,1)

NGARCHsigma_sq=NaN(rows(GARCHsigma),1);
NGARCHsigma_sq(1)=omega/(1-alpha*(1+theta^2)-beta);                         %This initializes at the unconditional variance implied by the model
                         
for i=1:(se-ss)
    NGARCHsigma_sq(i+1)=omega+alpha*(ret(i)-theta*sqrt(NGARCHsigma_sq(i)))^2+beta*NGARCHsigma_sq(i);
end
NGARCHsigma=sqrt(NGARCHsigma_sq);                                           %Computes volatility

% GJR(1,1) (also called THRESHOLD GARCH) model estimated by MLE, using
% Matlab's garchfit package
GJRspec=garchset('VarianceModel','GJR','Distribution','Gaussian','P',1,'Q',1);  %This is the way you tell Matlab to estimate a GJR and not a GARCH
[GJRcoeff, GJRerrors,GJRllf,GJRinnovation,GJRsigma,GJRsummary]=...
garchfit(GJRspec,Port(ss:se,:));
garchdisp(GJRcoeff,GJRerrors);

% EGARCH(1,1) model estimated by MLE, using Matlab's garchfit package
EGARCHspec=garchset('VarianceModel','EGARCH','Distribution','Gaussian','P',1,'Q',1);  %This is the way you tell Matlab to estimate a GJR and not a GARCH
[EGARCHcoeff, EGARCHerrors,EGARCHllf,EGARCHinnovation,EGARCHsigma,EGARCHsummary]=...  %By the way, this is how you break one line of command in Matlab
        garchfit(EGARCHspec,Port(ss:se,:));
garchdisp(EGARCHcoeff,EGARCHerrors);

disp('====================== SUMMARY OF COMPETING ASYMMETRIC GARCH MODELS =========================')

fprintf('\n');
disp('NGARCH(1,1) PARAMETERS');
fprintf('omega  ');  fprintf('%5.4f ',param_ng(1,1));fprintf('\n');
fprintf('alpha  ');  fprintf('%5.4f ',param_ng(2,1));fprintf('\n');
fprintf('theta  ');  fprintf('%5.4f ',param_ng(3,1));fprintf('\n');
fprintf('beta   ');  fprintf('%5.4f ',param_ng(4,1));fprintf('\n');
fprintf('MaxLik ');  fprintf('%5.4f ',mle_ng(1,1));fprintf('\n');
fprintf('Stationarity measure ');  fprintf('%5.4f ',param_ng(2,1)*(1+(param_ng(3,1)^2))+param_ng(4,1)); fprintf('\n');
fprintf('\n');

disp('GJR-GARCH(1,1) PARAMETERS');
garchdisp(GJRcoeff,GJRerrors); fprintf('\n');
fprintf('Stationarity measure ');  fprintf('%5.4f ',GJRcoeff.ARCH+GJRcoeff.GARCH+0.5*GJRcoeff.Leverage); fprintf('\n');

disp('EGARCH(1,1) PARAMETERS');
garchdisp(EGARCHcoeff,EGARCHerrors); fprintf('\n');
fprintf('Stationarity measure '); fprintf('%5.4f ',EGARCHcoeff.ARCH+EGARCHcoeff.GARCH+0.5*EGARCHcoeff.Leverage); fprintf('\n');

%Plots and compares alternative volatility dynamics
run Figure005.m