
disp('============= Computing Value at Risks  =============')

p_VaR=0.05;

% Estimation of the degrees of freedom for a standardized t-student via quasi maximum likelihood (i.e., taking the GJR standardized
% residuals as given)

cond_std=GJRsigma;
df_init=4;                                                                  %This is just an initial condition
[df,qmle]=fminsearch('logL1',df_init,[],Port(ss:se,:),cond_std); % This QMLE problem calls the used-defined function logL1_asym
                                                                            % Syntax:   [sumloglik] = logL1(df,ret,sigma)
                                                                            % Input:  df, number of degrees of freedom
                                                                            %         ret, vector of returns
                                                                            %         sigma, vector of filtered time-varying standard deviations
                                                                            % Output: Log-likelihood function 

% Estimation of the Cornish-Fisher expansion parameters
zeta_1=skewness(z_gjr);
zeta_2=kurtosis(z_gjr)-3;
inv=norminv(p_VaR,0,1);

% Computes quantiles for the different VaR definitions
q_norm=inv;
q_tstud=sqrt((df-2)/df)*tinv((p_VaR),df);                                   % Notice the standardization adjustment Var(z) = df/(df-2), which means that z is not 
                                                                            % standardized; if you produce 
                                                                            % inverse t-value critical points from a standardized t-Student -- as 
                                                                            % tinv((p_VaR) does -- then you have to adjust the critical value by de-
                                                                            % standardizing it, which is done dividing it by sqrt(df/(df-2)), that is 
                                                                            % multiplying by sqrt((df-2)/df)
q_CF=inv+(zeta_1/6)*(inv^2-1)+(zeta_2/24)*(inv^3-3*inv)-(zeta_1^2/36)*(2*(inv^3)-5*inv);

nforecasts=20;
for_cond_std_gjr=NaN(nforecasts,1);

% Predicted Conditional Standard Deviation from GJR-GARCH
f2=['01/07/2009';'08/07/2009';'15/07/2009';'22/07/2009';'28/07/2009'];
date_find2=datenum(f2,'dd/mm/yyyy');
index2=datefind(date_find2,date);
for i=1:index2(5)-index2(1)+1                                              % Forecasts from t+1 to the end of July 2009
   for_cond_std_gjr(i) = garchpred(spec_sim,Port(ss:se-1+i,1));
end

% 20-day 5% VaRs
unc_std=std(Port(ss:se,:));
VaR_norm=-unc_std*ones(1,nforecasts)*q_norm;
VaR_gjr=-for_cond_std_gjr'.*q_norm;
VaR_tstud=-for_cond_std_gjr'.*q_tstud;
VaR_CF=-for_cond_std_gjr'.*q_CF;
%plot Vars 
run Figure008.m