
disp('============== QMLE and MLE for Garch standardized t(d) ==============')
% Start by computing QMLE Estimates of a NGARCH with standardized t(d) innovations
df_init=10;                                                                 % Just an initial condition
[df,qmle]=fminsearch('logL1',df_init,[],Port(ss:se,:),sqrt(cond_var_ng)); % This performs QML estimation because cond_var_ng is taken as given
                                                                            % from question 3 above
disp('QML estimated degrees of freedom:'); 
fprintf('df  '); fprintf('%5.3f ',df); fprintf('\n');
df_QML=df;

% QQ-plot (constructed from scratch, without resorting to automatic normal command, for a change)
z_ngarch=sort(z_ng);
z=sort(Port(ss:se,:));
[R,C]=size(z);
rank=(1:R)';
n=length(z);

quant_tstud=tinv(((rank-0.5)/n),df);
cond_var_qmle=cond_var_ng;

% QQ-plot standardized returns vs. t~(df) (auto)
figure;
qqplot(sqrt((df-2)/df)*quant_tstud,z_ngarch);                              % See comment in line 544
set(gcf,'color','w');
title('QQ Plot of NGARCH Standardized Residuals vs. Standardized t(d) Distribution (QML Method)','fontname','garamond','fontsize',15);

% ML Estimation of NGARCH with standardized t(d)-distributed shocks
initial=[param_ng;10];                                                     % Initial conditions for all model parameters, not only the number of degrees of
[fit_par,mle]=fminsearch('logL2',initial,[],Port(ss:se,:));    % freedom
df_ML=fit_par(5,1);                                                        % logL2 is a user-defined function that computes the log-likelihood function for
                                                                           % a t-student NGARCH(1,1) model
                                                                           % Syntax: tloglik=logL2(par,y)
                                                                           % Inputs: par, vector of parameters to be estimated
                                                                           %         y, vector of data (returns)
disp('NGARCH estimated parameters (assuming std. t innovations):'); 
fprintf('omega  ');  fprintf('%5.3f ',fit_par(1,1));fprintf('\n');
fprintf('alpha  ');  fprintf('%5.3f ',fit_par(2,1));fprintf('\n');
fprintf('theta  ');  fprintf('%5.3f ',fit_par(3,1));fprintf('\n');
fprintf('beta   ');  fprintf('%5.3f ',fit_par(4,1));fprintf('\n');
fprintf('t~ d.f ');  fprintf('%5.3f ',fit_par(5,1));fprintf('\n'); 
 
disp('The implied persistence of the ML estimate of the t(d)-NGARCH(1,1) model is:');
persist=fit_par(2,1)*(1+(fit_par(3,1)^2))+fit_par(4,1);
fprintf('Persistence:  ');  fprintf('%5.3f ',persist);fprintf('\n');

disp('Comparing the results of QML and ML estimation:'); 
fprintf('QML estimate of d  ');  fprintf('%5.3f ',df_QML);fprintf('\n');
fprintf('ML estimate of d   ');  fprintf('%5.3f ',df_ML);fprintf('\n');

df_mle=fit_par(5,1);
quant_ts_mle=tinv(((rank-0.5)/n),df_mle);
[a,z_lev_mle,condvar_mle]=ngarch(fit_par,Port(ss:se,:));
z_mle=sort(z_lev_mle);

% QQ-plot
figure;
qqplot(sqrt((df_mle-2)/df_mle)*quant_ts_mle,z_mle);
set(gcf,'color','w');
title('QQ Plot of NGARCH Standardized Residuals vs. Standardized t(d) Distribution (ML Method)','fontname','garamond','fontsize',15);

% Compare the conditional volatilities from the two sets of estimates: QML vs. ML
figure;
t=1:length(Port(ss:se,:));
plot(t',sqrt(cond_var_qmle),'r',t',sqrt(condvar_mle),'b');
set(gca,'xtick',index,'xlim',[1 rows(t')]);
set(gca,'xticklabel','Jul2008|Sep2008|Nov2008|Feb2009|Apr2009|Jun2009|',...
    'xlim',[1 length(t')+1]);
%set(gca,'yticklabel',[0 0.002 0.006 0.010 0.014 0.018 0.022]);
ylabel('Volatilities');
xlabel('Time');
title('Comparing the Effects of QML vs. ML Methods','fontname','garamond','fontsize',15,'Color', [.3 .3 .3]);
h=legend('QML standardized t(d)', 'ML standardized t(d)',2);
set(h,'fontsize',12);
set(gcf,'color','w');
set(gca,'Box', 'off', 'TickDir', 'out', 'TickLength', [.02 .02],'XMinorTick', 'off','YMinorTick', 'off','XColor', [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth', 1, 'FontName', 'Times');

% Compare the conditional volatilities filtered from the Gaussian NGARCH, as well as the two cases of t-Student NGARCH 
figure;
t=1:length(Port(ss:se,:));
plot(t',sqrt(cond_var_ng),'*y',t',sqrt(((df_QML-2)/df_QML).*cond_var_qmle),'r',t',sqrt(((df_ML-2)/df_ML).*condvar_mle),'b');
set(gca,'xtick',index,'xlim',[1 rows(t')]);
set(gca,'xticklabel','Jul2008|Sep2008|Nov2008|Feb2009|Apr2009|Jun2009|',...
    'xlim',[1 length(t')+1]);
%set(gca,'yticklabel',[0 0.0002 0.0004 0.0006 0.0008 0.0010 0.0012]);
ylabel('Volatilities');
xlabel('Date');
title('Question 6: Comparing t-Student vs. Gaussian NGARCH Models','fontname','garamond','fontsize',15,'Color', [.3 .3 .3]);
h=legend('NGARCH with Gaussian innovations', 'QMLE standardized t(d)', 'MLE standardized t(d)',2);
set(h,'fontsize',12);
set(gcf,'color','w');
set(gca,'Box', 'off', 'TickDir', 'out', 'TickLength', [.02 .02],'XMinorTick', 'off','YMinorTick', 'off','XColor', [.3 .3 .3],'YColor',[.3 .3 .3],'LineWidth', 1, 'FontName', 'Times');

