disp('============  Extreme Value Theory (EVT) VaR Estimates vs. MLE for NGARCH standardized t(d) ============')
p_VaR=0.0001;

% Hill Estimator
std_loss=-z_ng;
[sorted_loss I]=sort(std_loss,'descend');
u=quantile(sorted_loss,0.96);                                              % This is the critical threshold choice
tail=sorted_loss(sorted_loss>u);
Tu=length(tail);
T=length(std_loss);
xi=(1/Tu)*sum(log(tail./u));

% Quantiles
q_EVT=u*(p_VaR./(Tu/T)).^(-xi);
q_norm=norminv(1-p_VaR,0,1);
q_tstud=sqrt((df-2)/df)*tinv((1-p_VaR),df);                                % See comment in line 544
zeta_1=skewness(z_ng);
zeta_2=kurtosis(z_ng)-3;
inv=norminv(p_VaR,0,1);
q_CF=inv+(zeta_1/6)*(inv^2-1)+(zeta_2/24)*(inv^3-3*inv)-(zeta_1^2/36)*(2*(inv^3)-5*inv);

% Computes 1-day 0.01% VaRs
cond_std=sqrt(cond_var_ng);
VaR_norm=cond_std.*q_norm;
VaR_EVT=cond_std.*q_EVT;
VaR_tstud=cond_std.*q_tstud;
VaR_CF=-cond_std.*q_CF;

fprintf('Estimated VaRs, p= '); fprintf('%5.4f',p_VaR);fprintf('\n');
fprintf('Normal NGARCH          ');  fprintf('%5.3f ',VaR_norm(T,1));fprintf('\n');
fprintf('Std-T  NGARCH          ');  fprintf('%5.3f ',VaR_tstud(T,1));fprintf('\n');
fprintf('Cornish Fisher         ');  fprintf('%5.3f ',VaR_CF(T,1));fprintf('\n');
fprintf('Extreme Value (Hill)   ');  fprintf('%5.3f ',VaR_EVT(T,1));fprintf('\n');
 
% QQ-plot(auto)
Fy=u*((I-0.5)./Tu).^(-xi);
x=Fy(I<=Tu);
figure
qqplot(x,tail);
set(gcf,'color','w');
title('QQ Plot of Sample Data versus the EVT Distribution (4% threshold)','fontname','garamond','fontsize',15);

% Repeat HIll EVT calculations when the threshold is increased to 8%
std_loss=-z_ng;
[sorted_loss I]=sort(std_loss,'descend');
u2=quantile(sorted_loss,0.92);                                             % This is the critical threshold choice
tail2=sorted_loss(sorted_loss>u2);
Tu2=length(tail2);
T=length(std_loss);
xi2=(1/Tu2)*sum(log(tail2./u2));
 
% QQ-plot(auto)
Fy2=u2*((I-0.5)./Tu2).^(-xi2);
x2=Fy2(I<=Tu2);
figure
qqplot(x2,tail2);
set(gcf,'color','w');
title('QQ Plot of Sample Data versus the EVT Distribution (8% threshold)','fontname','garamond','fontsize',15);

label=strvcat(' 4% threshold ', '8% threshold ');
figure;
for i=1:2
    subplot(1,2,i)
    if i==1; 
        qqplot(x,tail);
    else
        qqplot(x2,tail2);
    end
    set(gcf,'color','w');
    tit=strcat('Q7: QQ Plots as the threshold level doubles: ',label(i,:));
    title(tit);
end
