%% Testing for normality of (raw and unconditionally standardized portfolio returns

disp('================  Test for normality of raw portfolio returns ================')
%Q2: QQ-Plots -- Unconditional returns (raw and standardized with unconditional variance)
unc_std=std(Port(ss:se,:));                                       %This just the unconditional sample standard deviation over our sample
std_portret=(Port(ss:se,:)-mean(Port(ss:se,:)))./unc_std; %Standardizing by the unconditional st. dev. is simply equivalent to divide by
                                                                            %a constant
RET=[Port(ss:se,:) std_portret];
label=strvcat(' Raw Returns', ' Uncond. Standardized Returns');             %These are useful labels to be applied to the top of your plots

figure(3);
for i=1:2
    subplot(1,2,i)
    qqplot(RET(:,i));
    set(gcf,'color','w');
    tit=strcat('Q2: QQ-plot: ',label(i,:));
    title(tit);
    %set(gca,'ylim',[-8 12]);
end
                                                                            %qqplot produces a Quantile-quantile plot (see lecture notes)
                                                                            %Syntax: qqplot(X)
                                                                            % It displays a quantile-quantile plot of the sample quantiles of X versus 
                                                                            % theoretical quantiles from a normal distribution. If the distribution of X is 
                                                                            % normal, the plot will be close to linear.
                                                                            % The plot has the sample data displayed with the plot symbol '+'. Superimposed 
                                                                            % on the plot is a line joining the first and third quartiles of each 
                                                                            % distribution (this is a robust linear fit of the order statistics of the two 
                                                                            % samples). This line is extrapolated out to the ends of the sample to help 
                                                                            % evaluate the linearity of the data.
                                                                            %qqplot(X,Y) displays a quantile-quantile plot of two samples. If the samples 
                                                                            %do come from the same distribution, the plot will be linear.
                                                                            %qqplot(X,PD) makes an empirical quantile-quantile plot of the quantiles of the 
                                                                            %data in the vector X versus the quantiles of the distribution specified by PD, 
                                                                            %a ProbDist object of the ProbDistUnivParam class or ProbDistUnivKernel class.
% Kernel Density Fit Comparison
norm=randn(1000*rows(RET(:,1)),1);                                          %randn generates standard normally distributed pseudorandom numbers
                                                                            %Notice that to obtain a smooth Gaussian bell-shaped curve, you should generate
                                                                            %a large number of values
norm1=mean(RET(:,1))+std(RET(:,1)).*norm;                                   %The Gaussian random numbers will have the same mean and variance as raw 
                                                                            %portfolio returns.
norm2=mean(RET(:,2))+std(RET(:,2)).*norm;                                   %The Gaussian random numbers will have the same mean and variance as standardized 
                                                                            %portfolio returns (NOTE: std(RET(:,2))should equal 1).                            
%This is the kernel density estimator applied to the pseudorandom normal numbers
[Fnorm1,XInorm1]=ksdensity(norm1,'kernel','normal');                        %ksdensity produces a kernel smoothing density estimate
[Fnorm2,XInorm2]=ksdensity(norm2,'kernel','normal');                        %Syntax: [f,xi] = ksdensity(x)
                                                                            %[f,xi] = ksdensity(x) computes a probability density estimate of the sample 
                                                                            %in the vector x. f is the vector of density values evaluated at the points in 
                                                                            %xi. The estimate is based on a normal kernel function, using a window parameter 
                                                                            %(bandwidth) that is a function of the number of points in x. The density is 
                                                                            %evaluated at 100 equally spaced points that cover the range of the data in x. 
                                                                            %
                                                                            %[...] = ksdensity(...,'Name',value) specifies one or more optional parameter 
                                                                            %name/value pairs to control the density estimation. Valid parameter strings 
                                                                            %and their possible values are as follows:
                                                                            %censoring:   A logical vector of the same length as x, indicating which 
                                                                            % entries are censoring times. Default is no censoring.
                                                                            %kernel:      The type of kernel smoother to use. Choose the value as 'normal' 
                                                                            %             (default), 'box', 'triangle', 'epanechnikov'
                                                                            %npoints:     The number of equally spaced points in xi. Default is 100.
                                                                            %support:     'unbounded' allows the density to extend over the whole real line
                                                                            %             (default); 'positive' restricts the density to positive values; a 
                                                                            %             two-element vector gives finite lower and upper bounds for the 
                                                                            %             support of the density.
                                                                            %The bandwidth of the kernel-smoothing window. The default is optimal for 
                                                                            % estimating normal densities, but you may want to choose a smaller value to 
                                                                            %reveal features such as multiple modes. 
                                                                            %function:    The function type to estimate, chosen from among 'pdf', 'cdf', 
                                                                            %             'icdf', 'survivor', 'cumhazard'
[F1,XI1]=ksdensity(RET(:,1),'kernel','normal');
[F2,XI2]=ksdensity(RET(:,2),'kernel','normal');

figure(4)
subplot(2,1,1)
plot(XInorm1,Fnorm1,'b', 'LineWidth',2); hold on; plot(XI1,F1,'r', 'LineWidth',3);
legend('Normal Distribution','Unconditional distribution',1);
title('Q2: Kernel Density Estimates: Gaussian vs. Raw Ptf. Returns','fontname','Garamond','fontsize',15);
set(gca,'fontname','garamond','fontsize',12);
set(gcf,'color','w');
subplot(2,1,2)
plot(XInorm2,Fnorm2,'b', 'LineWidth',2); hold on; plot(XI2,F2,'r', 'LineWidth',3);
legend('Normal Distribution','Unconditional distribution',1);
title('Q2: Kernel Density Estimates: Gaussian vs. (Unconditionally) Standardized Ptf. Returns','fontname','Garamond','fontsize',15);
set(gca,'fontname','garamond','fontsize',12);
set(gcf,'color','w');

% Jarque-Bera tests
[h,p_val,jbstat,critval] = jbtest(Port);
[h_std,p_val_std,jbstat_std,critval_std] = jbtest(std_portret);

col1=strvcat(' ','JB statistic:  ','Critical val:','P-value:','Reject H0?');
col2=strvcat('RETURNS     ',num2str(jbstat),num2str(critval),num2str(p_val),num2str(h));
col3=strvcat('STD. RETURNS ',num2str(jbstat_std),num2str(critval_std),num2str(p_val_std),num2str(h_std));
mat=[col1,col2,col3];
disp(['Jarque-Bera test for normality (5%)']);
disp(mat);fprintf('\n');

disp('----------------------  End of QUESTION 2  ----------------------')

